@@ -12,9 +12,11 @@
 #
 import os
 import unittest
+
 from ipykernel.tests.utils import execute, wait_for_idle
-from sos_notebook.test_utils import sos_kernel, get_result, get_display_data, \
-    clear_channels
+from sos_notebook.test_utils import (clear_channels, get_display_data,
+                                     get_result, sos_kernel)
+
 
 class TestJavaScriptKernel(unittest.TestCase):
     #
